@@ -16,7 +16,7 @@ from .handlers import (
     StartHandler,
     TextHandler,
 )
-from .keyboards import InlineKeyboard
+from .keyboards import InlineKeyboard, ReplyKeyboard
 from .loader import app, texts
 
 __all__ = [
@@ -39,4 +39,5 @@ __all__ = [
     "MessageContext",
     "QueryContext",
     "TextContext",
+    "ReplyKeyboard",
 ]
