@@ -9,4 +9,4 @@ class InlineKeyboard(InlineKeyboardMarkup):
     buttons: Sequence[ButtonRow]
 
     def __init__(self, *buttons: ButtonRow) -> None:
-        super().__init__(buttons)
+        super().__init__(buttons or self.buttons)
