@@ -15,25 +15,25 @@ class Update(TelegramObject):
 
     @property
     def message(self) -> Message:
-        raw = self.get_validated_field("message", self.raw.message)
+        raw = self.check_field("message", self.raw.message)
         return Message(raw)
 
     @property
     def query(self) -> Query:
-        raw = self.get_validated_field("query", self.raw.callback_query)
+        raw = self.check_field("query", self.raw.callback_query)
         return Query(raw)
 
     @property
     def effective_message(self) -> Message:
-        raw = self.get_validated_field("effective_message", self.raw.effective_message)
+        raw = self.check_field("effective_message", self.raw.effective_message)
         return Message(raw)
 
     @property
     def effective_chat(self) -> Chat:
-        raw = self.get_validated_field("effective_chat", self.raw.effective_chat)
+        raw = self.check_field("effective_chat", self.raw.effective_chat)
         return Chat(raw)
 
     @property
     def effective_user(self) -> User:
-        raw = self.get_validated_field("effective_user", self.raw.effective_user)
+        raw = self.check_field("effective_user", self.raw.effective_user)
         return User(raw)
